pub enum VReg {
RealRegister(usize),
Virtual(usize),
Spilled(usize),
}Variants
RealRegister(usize)
VReg::RealRegister represents a register that exists in the target architecture.
Virtual(usize)
VReg::Virtual represents a virtual register, of which there are unlimited. These are
converted into real registers or spilled registers depending on the register allocator.
Spilled(usize)
VReg::Spilled represents a spilled value on the stack. This variant is used when the
register allocator could not fit a value into the limited registers of the target
architecture.